=========
History
=========

v0.3.0 (2019-03-15)
--------------------
* More helper functions added to utils
* Tradebook class enhanced
* A Meta class added for event based simulation

v0.2.0 (2018-12-26)
--------------------
* Backtest from different formats added
* Rolling function added


v0.1.0. (2018-10-13)
----------------------

* First release on PyPI
